@@ -3,8 +3,8 @@
 from openshift.dynamic.exceptions import ResourceNotFoundError
 
 from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
-from ocp_resources.resource import TIMEOUT, NamespacedResource
-from ocp_resources.utils import TimeoutSampler
+from ocp_resources.resource import NamespacedResource
+from ocp_resources.utils import TimeoutSampler, TimeoutWatch
 from ocp_resources.virtual_machine import VirtualMachine
 
 
@@ -24,6 +24,8 @@ class VirtualMachineRestore(NamespacedResource):
         client=None,
         teardown=True,
         yaml_file=None,
+        delete_timeout=TIMEOUT_4MINUTES,
+        **kwargs,
     ):
         super().__init__(
             name=name,
@@ -31,25 +33,24 @@ class VirtualMachineRestore(NamespacedResource):
             client=client,
             teardown=teardown,
             yaml_file=yaml_file,
+            delete_timeout=delete_timeout,
+            **kwargs,
         )
         self.vm_name = vm_name
         self.snapshot_name = snapshot_name
 
     def to_dict(self):
-        res = super().to_dict()
-        if self.yaml_file:
-            return res
+        super().to_dict()
+        if not self.yaml_file:
+            spec = self.res.setdefault("spec", {})
+            spec.setdefault("target", {})[
+                "apiGroup"
+            ] = NamespacedResource.ApiGroup.KUBEVIRT_IO
+            spec["target"]["kind"] = VirtualMachine.kind
+            spec["target"]["name"] = self.vm_name
+            spec["virtualMachineSnapshotName"] = self.snapshot_name
 
-        spec = res.setdefault("spec", {})
-        spec.setdefault("target", {})[
-            "apiGroup"
-        ] = NamespacedResource.ApiGroup.KUBEVIRT_IO
-        spec["target"]["kind"] = VirtualMachine.kind
-        spec["target"]["name"] = self.vm_name
-        spec["virtualMachineSnapshotName"] = self.snapshot_name
-        return res
-
-    def wait_complete(self, status=True, timeout=TIMEOUT):
+    def wait_complete(self, status=True, timeout=TIMEOUT_4MINUTES):
         """
         Wait for VirtualMachineRestore to be in status complete
 
@@ -64,9 +65,18 @@ class VirtualMachineRestore(NamespacedResource):
             f"Wait for {self.kind} {self.name} status to be complete = {status}"
         )
 
-        samples = TimeoutSampler(
+        timeout_watcher = TimeoutWatch(timeout=timeout)
+        for sample in TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
+            func=lambda: self.exists,
+        ):
+            if sample:
+                break
+
+        samples = TimeoutSampler(
+            wait_timeout=timeout_watcher.remaining_time(),
+            sleep=1,
             exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
             func=lambda: self.instance.get("status", {}).get("complete") == status,
         )
